#
# spec file for package printer-driver-brlaser
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2020 Xu Zhao (i@xuzhao.net)
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           printer-driver-brlaser
Version:        6.2.7
Release:        1.1
Summary:        Driver for (some) Brother laster printers
License:        GPL-2.0-or-later
Group:          Hardware/Printing
URL:            https://github.com/Owl-Maintain/brlaser
Source:         https://github.com/Owl-Maintain/brlaser/archive/refs/tags/v%{version}.tar.gz#/brlaser-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  cups-ddk
BuildRequires:  cups-devel
BuildRequires:  cups-rpm-helper
BuildRequires:  gcc-c++

%description
Most Brother printers support a standard printer language such as
PCL or PostScript, but not all do. If you have a monochrome Brother
laser printer (or multi-function device) and the other open source
drivers don't work, this one might help.

The following printers have been reported to work with this driver:

    Brother DCP-1510 series
    Brother DCP-1600 series
    Brother DCP-1610W series
    Brother DCP-7010
    Brother DCP-7020
    Brother DCP-7030
    Brother DCP-7040
    Brother DCP-7055
    Brother DCP-7055W
    Brother DCP-7060D
    Brother DCP-7065DN
    Brother DCP-7070DW
    Brother DCP-7080
    Brother DCP-7080D
    Brother DCP-8065DN
    Brother DCP-B7500D series
    Brother DCP-L2500D series
    Brother DCP-L2510D series
    Brother DCP-L2520D series
    Brother DCP-L2520DW series
    Brother DCP-L2537DW
    Brother DCP-L2540DW series
    Brother DCP-L2550DW series
    Brother DCP-L2560DW series
    Brother FAX-2820
    Brother FAX-2840
    Brother HL-1110 series
    Brother HL-1200 series
    Brother HL-2030 series
    Brother HL-2130 series
    Brother HL-2140 series
    Brother HL-2150N
    Brother HL-2220 series
    Brother HL-2230 series
    Brother HL-2240 series
    Brother HL-2240D series
    Brother HL-2250DN series
    Brother HL-2260
    Brother HL-2260D
    Brother HL-2270DW series
    Brother HL-2280DW
    Brother HL-5030 series
    Brother HL-5040 series
    Brother HL-5140 series
    Brother HL-5370DW series
    Brother HL-5450DN series
    Brother HL-L2300D series
    Brother HL-L2305 series
    Brother HL-L2310D series
    Brother HL-L2320D series
    Brother HL-L2335D series
    Brother HL-L2340D series
    Brother HL-L2350DW series
    Brother HL-L2360D series
    Brother HL-L2370DN series
    Brother HL-L2375DW series
    Brother HL-L2380DW series
    Brother HL-L2390DW
    Brother HL-L2400DW
    Brother HL-L2402D
    Brother HL-L2405W
    Brother HL-L5000D series
    Brother MFC-1810 series
    Brother MFC-1910W series
    Brother MFC-7240
    Brother MFC-7320
    Brother MFC-7340
    Brother MFC-7360N
    Brother MFC-7365DN
    Brother MFC-7420
    Brother MFC-7440N
    Brother MFC-7460DN
    Brother MFC-7860DW
    Brother MFC-8440
    Brother MFC-8710DW
    Brother MFC-8860DN
    Brother MFC-9160
    Brother MFC-L2690DW
    Brother MFC-L2700DN series
    Brother MFC-L2700DW series
    Brother MFC-L2710DN series
    Brother MFC-L2710DW series
    Brother MFC-L2750DW series
    Fuji Xerox DocuPrint P265 dw
    Lenovo LJ2650DN

%prep
%setup -q -n brlaser-%{version}

%build
%cmake
%cmake_build
ppdc brlaser.drv

%check
%ctest

%install
%cmake_install
# we use compiled ppds instead
rm %{buildroot}%{_datadir}/cups/drv/brlaser.drv
# install compiled ppds
install -Dm644 build/ppd/* -t %{buildroot}%{_datadir}/cups/model/brlaser

%files
%defattr(-,root,root)
%license COPYING
%doc README.md
%dir %{_prefix}/lib/cups
%dir %{_prefix}/lib/cups/filter
%{_prefix}/lib/cups/filter/rastertobrlaser
%dir %{_datadir}/cups
%dir %{_datadir}/cups/model
%{_datadir}/cups/model/brlaser

%changelog
* Sun Mar  2 2025 Adam Mizerski <adam@mizerski.pl>
- Update to 6.2.7
  - New printer entries:
  - Brother DCP-7010
  - Brother DCP-B7500D series
  - Brother DCP-L2560DW series
  - Brother HL-2240 series
  - Brother HL-2260D
  - Brother HL-5140 series
  - Brother HL-5370DW series
  - Brother HL-5450DN series
  - Brother HL-L2402D
  - Brother MFC-8440
  - Brother MFC-L2690DW
  - Brother HL-L2400DW
  - Brother HL-L2405W
  - Added printer entries for "Test Drivers".
  - Code Changes:
  - Correct PCFileName for DocuPrint P265 dw
  - Replaced Duplex normal with Duplex rotated
  - Both Duplex & Tumble use PLC &l2S
  - Issues Resolved:
  - #11 Duplex long-edge actually prints duplex short-edge
  - #22 All reverse sides are unreadable with artefactsbug (duplex long-edge)
  - #23 Incorrect Duplex & Tumble Check Statement
  - Merged pull requests:
  - #6 Fedora also packages brlaser; Thanks @ondrejbudai
  - #7 Removed duplicate line from Compatible Issue Template; Thanks @erooke
  - #8 Added Brother HL-5370DW series; Thanks @erooke
  - #25 Updated ChangeLog to include releases from 6.1-6.2.6; Thanks @qwertychouskie
  - #9 Release version is now 6.2.7; Thanks @qwertychouskie
- Update to 6.2.6
  - New printer entries:
  - Brother FAX-2840
  - Brother HL-2260
  - Brother HL-L2335D series
  - Brother MFC-7860DW
  - Brother MFC-9160
  - Notes:
  - The repository has been cleaned up
  - All entries brlaser.drv.in and README.md both follow a set naming convention
  - Commits where "rewritten correctly" to follow the standard conventions and then squashed
- Update to 6.2.5
  - Merge pull requests:
  - QORTEC#2 Add Tumble support; Thanks @evanmiller
  - QORTEC#3 Fix build under Fedora 38; Thanks @ondrejbudai
  - New printer entries:
  - Brother FAX-2820
  - Brother DCP-1610W
  - Code Changes:
  - #2 Added \033&l1S for duplex no tumble printing, as well as logic print duplex with and without tumble.
  - #3 Explicitly include cstdint in test/tempfile.h, so uint8_t is correctly defined.
  - Issues Resolved:
  - #3 Fixed building under Fedora 38; error: 'uint8_t' was not declared in this scope.
* Tue Mar 28 2023 lnussel@suse.de
- Update to version 6+git20230220.2a49e32:
  * Fix build with GCC 13
  * Fix MFC-7460DN PPD file name
* Wed Aug 19 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Sat Jul 11 2020 seife+obs@b1-systems.com
- Update to version 6+git20200420.9d7ddda:
  * Arrange blocks in bands of 128 lines
  - this is more similar to what the Brother driver does and
    fixes #52, #40 etc
  * Tweak compiler flags
  * Be tolerant of zero-page jobs
  * Add some new printer definitions
  - HL-2375DW, HL-2390DW, MFC-7420, MFC-7460DN, DCP-L2520DW
  * Update README.md
* Tue Jun  2 2020 Ludwig Nussel <lnussel@suse.de>
- use cups-rpm-helper to have automatic printer driver provides (boo#1172407)
* Thu Apr 16 2020 i@xuzhao.net
- Update to version 6+git20191118.2f63d0a:
  * Package available on guix, too
  * Bump version number
  * Version 6
  * Add Brother HL-2270DW
  * add gedit backup file to .gitignore (*~)
  * Add a bunch of printers
  * Don't compress across bands (#39)
  * Version 5
  * Brother HL-1110
  * Add a bunch of printer stanzas
* Sat Apr 11 2020 Xu Zhao <i@xuzhao.net>
- Update to version 6:
  * Added support for some more Brother HL-series printers.
    Brother HL-2030 series
    Brother HL-2140 series
    Brother HL-2220 series
    Brother HL-2270DW series
    Brother HL-5030 series
    Brother DCP-L2520D series
- Update from version 5:
  * Fixed problems with Brother HL-series printers in 600 dpi mode.
  * Added brlaser.drv stanzas for several new printers.
- Update from version 4:
  * Added several printers
  * Merged duplex printing support
  * Switched to a CMake build system
- Removed patches as they are already merged:
  0001-mark-DCP-7055W-as-supported.diff
  0002-Add-Brother-DCP1510.diff
  0003-Add-missing-include-string.diff
* Fri Jun 17 2016 lnussel@suse.de
- Update to version 3+git20160302.03bb366:
  * Kill a harmless dead store
  * Fix lest.hpp dependency for the tests.
  * Add Brother DCP-7055
  * Misc cleanups, mostly in the test code
  * Reject unexpected raster formats
  * Use cups-config --ldflags
  * Refuse to build without a C++11 compiler
- fetch patches from pull requests:
  0001-mark-DCP-7055W-as-supported.diff (was brlaser-br7055w.diff)
  0002-Add-Brother-DCP1510.diff
  0003-Add-missing-include-string.diff (fixes boo#985119)
- remove SLE11 and SLE10 noise from spec file again, doesn't build there
  anyways.
* Thu Jan 28 2016 jsmeix@suse.de
- Make it build for SLE12 with traditional CUPS 1.5.4 to ensure
  it works on SLE12 both with CUPS 1.7.5 and CUPS 1.5.4 because
  for SLE12 by default CUPS 1.7.5 is provided and alternatively
  CUPS 1.5.4 is provided in the "legacy" module, cf.
  https://www.suse.com/releasenotes/x86_64/SUSE-SLES/12/
- Prepare building it for SLE11 via "BuildRequires cupsddk"
  because on SLE11 with its CUPS 1.3.9 there is the separated
  package cupsddk (otherwise use cups-ddk a sub-package of cups).
- For SLE11 redefine _libexecdir to be "/usr/lib" in any case
  because on SLE11 x86_64 it evaluates to "/usr/lib64" which
  is wrong in particular for CUPS filters and backends, cf.
  https://bugzilla.opensuse.org/show_bug.cgi?id=575544#c2
- Prepare building it for SLE10 (cf. "SLE10" spec file comments).
- Have Source0 as .tar.gz (instead .tar.xz) because .tar.gz
  "just works" on SLE11 and SLE10 and the .tar.gz is only 2K
  bigger than the .tar.xz (25K versus 23K as of this writing).
- Regardless that it is prepared for building on SLE11 and SLE10
  (see gutenprint.spec and hplip.spec how to do that)
  currently it cannot build for SLE11 and SLE10
  because "autoreconf -fi" fails with
  "error: Autoconf version 2.68 or higher is required".
  On SLE11 there is autoconf-2.63 and on SLE10 there is
  autoconf-2.59 so that currently building for SLE11 and SLE10
  is still disabled.
* Thu Jan 28 2016 lnussel@suse.de
- require python-cups to get automatic printer driver provides
- run spec-cleaner
* Wed Jan 27 2016 lnussel@suse.de
- install compiled ppds
* Fri Nov 27 2015 lnussel@suse.de
- new package
